from django.conf import settings


def clean_setting(
    name: str,
    default_value: object,
    min_value: int = None,
    max_value: int = None,
    required_type: type = None
):
    """cleans the input for a custom setting

    Will use `default_value` if settings does not exit or has the wrong type
    or is outside define boundaries (for int only)

    Need to define `required_type` if `default_value` is `None`

    Will assume `min_value` of 0 for int (can be overriden)

    Returns cleaned value for setting
    """
    if default_value is None and not required_type:
        raise ValueError('You must specify a required_type for None defaults')

    if not required_type:
        required_type = type(default_value)

    if min_value is None and required_type == int:
        min_value = 0

    if not hasattr(settings, name):
        cleaned_value = default_value
    else:
        if (isinstance(getattr(settings, name), required_type)
            and (min_value is None or getattr(settings, name) >= min_value)
            and (max_value is None or getattr(settings, name) <= max_value)
        ):
            cleaned_value = getattr(settings, name)
        else:
            logger.warn(
                'You setting for {} it not valid. Please correct it. '
                'Using default for now: {}'.format(
                    name,
                    default_value
                )
            )
            cleaned_value = default_value
    return cleaned_value



from django.db import models


# Create your models here.

class AaTimezones(models.Model):
    """Meta model for app permissions"""

    class Meta:
        managed = False
        default_permissions = ()
        permissions = (
            ('basic_access', 'Can access this app'),
        )



from django.conf import settings
from .utils import clean_setting

# set default panels if none are set in local.py
AA_TIMEZONES_ADDITIONAL_PANELS = clean_setting(
    'AA_TIMEZONES_ADDITIONAL_PANELS', [
        {
            'timezoneName': 'US/Pacific',
            'panelTitle': 'US / Pacific',
            'panelId': 'us-pacific'
        },
        {
            'timezoneName': 'US/Mountain',
            'panelTitle': 'US / Mountain',
            'panelId': 'us-mountain'
        },
        {
            'timezoneName': 'US/Central',
            'panelTitle': 'US / Central',
            'panelId': 'us-central'
        },
        {
            'timezoneName': 'US/Eastern',
            'panelTitle': 'US / Eastern',
            'panelId': 'us-eastern'
        },
        {
            'timezoneName': 'Europe/London',
            'panelTitle': 'EU / Western',
            'panelId': 'eu-western'
        },
        {
            'timezoneName': 'Europe/Berlin',
            'panelTitle': 'EU / Central',
            'panelId': 'eu-central'
        },
        {
            'timezoneName': 'Europe/Istanbul',
            'panelTitle': 'EU / Eastern',
            'panelId': 'eu-eastern'
        },
        {
            'timezoneName': 'Europe/Moscow',
            'panelTitle': 'Russia / Moscow',
            'panelId': 'russia-moscow'
        },
        {
            'timezoneName': 'Asia/Shanghai',
            'panelTitle': 'Russia / Siberia & China / Shanghai',
            'panelId': 'asia-shanghai'
        },
        {
            'timezoneName': 'Australia/ACT',
            'panelTitle': 'Australia / Sydney',
            'panelId': 'australia-atc'
        }
    ]
)
